@@ -13,7 +13,7 @@ $WGET = "/usr/bin/wget";
 $LYNX = "NO";
 #$SED = "/bin/sed";
 $GREP = "/bin/grep";
-$RECODE = "NO"; #"NO"; -- dont use recode, it is not widely available
+$RECODE = "NO"; #"/usr/bin/recode"; -- dont use recode, it is not widely available
 # Directories
 $prefix="/home/chs/usr";
 $datadir="${prefix}/share";
