@@ -618,14 +618,13 @@ AccountNumberCheck::Result method_63(const int *account, int *weight) {
     if (0 != account[0])
 	return AccountNumberCheck::ERROR; // Added by Jens Gecius, check on invalid accountIDs
     number2Array("0121212000", weight);
-    AccountNumberCheck::Result tmp = algo01(10, weight, true, 8, account);
-    if (AccountNumberCheck::OK == tmp)
-	return AccountNumberCheck::OK;
-    else {
-	// shift left, add 00 as subaccount id and try again
+    if (0 == account[0] && 0 == account[1] && 0 == account[2]) {
+	// shift left, add 00 as subaccount id
 	int account_buf[10];
 	number2Array(array2Number(account).substr(2) + "00", account_buf);
 	return algo01(10, weight, true, 8, account_buf);
+    } else {
+	return algo01(10, weight, true, 8, account);
     }
 }
 AccountNumberCheck::Result method_64(const int *account, int *weight) {
@@ -1086,7 +1085,7 @@ AccountNumberCheck::Result method_96(const int *account, int *weight) {
     if (AccountNumberCheck::OK == algo01(10, weight, true, 10, account))
 	return AccountNumberCheck::OK;
     std::string acc10 = array2Number(account);
-    if (acc10 > "0001300000" || acc10 < "0099399999")
+    if (acc10 > "0001300000" && acc10 < "0099399999")
 	return AccountNumberCheck::OK;
     return AccountNumberCheck::ERROR;
 }
